# Install PyRIT

To install PyRIT, make sure you have Python 3.10 installed using `python --version`.
Alternatively, create a conda environment as follows

```
conda create -y -n <environment-name> python=3.10
```
followed by `conda activate <environment-name>`

Once the environment with the correct Python version is set up, run

```
pip install pyrit
```

Next, check out our [docs](../../doc/) and run the notebooks in your environment!
